==> nextcloud-22.2.6.tgz: nextcloud/apps/user_status/l10n/es.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Estados recientes",
    "In a meeting" : "En una reunión",
    "Commuting" : "De viaje",
    "Out sick" : "Ausente por enfermedad",
    "Vacationing" : "De vacaciones",
    "Working remotely" : "Teletrabajando",
    "In a call" : "En una llamada",
    "User status" : "Estado del usuario",
    "View profile" : "Ver perfil",
    "Clear status message after" : "Borrar mensaje de estado después de",
    "What is your status?" : "¿Cuál es su estado?",
    "Set status" : "Configurar estado",
    "Online status" : "Estado en línea",
    "Status message" : "Mensaje de estado",
    "Clear status message" : "Borrar mensaje de estado",
    "Set status message" : "Ajustar el mensaje de estado",
    "There was an error saving the status" : "Ha habido un error al guardar el estado",
    "There was an error clearing the status" : "Ha habido un error al eliminar el estado",
    "No recent status changes" : "No hay cambios de estado recientes",
    "Away" : "Ausente",
    "Do not disturb" : "No molestar",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "No eliminar",
    "Today" : "Hoy",
    "This week" : "Esta semana",
    "Online" : "En línea",
    "Invisible" : "Invisible",
    "Offline" : "Sin conexión",
    "There was an error saving the new status" : "Ha habido un error al guardar el nuevo estado",
    "30 minutes" : "30 minutos",
    "1 hour" : "1 hora",
    "4 hours" : "4 horas",
    "Mute all notifications" : "Silenciar todas las notificaciones",
    "Appear offline" : "Aparecer sin conexión",
    "What's your status?" : "¿Cuál es tu estado?"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.8.tgz: nextcloud/apps/user_status/l10n/es.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Estados recientes",
    "In a meeting" : "En una reunión",
    "Commuting" : "De viaje",
    "Out sick" : "Ausente por enfermedad",
    "Vacationing" : "De vacaciones",
    "Working remotely" : "Teletrabajando",
    "In a call" : "En una llamada",
    "User status" : "Estado del usuario",
    "View profile" : "Ver perfil",
    "Clear status after" : "Eliminar el estado después de",
    "What is your status?" : "¿Cuál es su estado?",
    "Set status" : "Configurar estado",
    "Online status" : "Estado en línea",
    "Status message" : "Mensaje de estado",
    "Clear status message" : "Borrar mensaje de estado",
    "Set status message" : "Ajustar el mensaje de estado",
    "There was an error saving the status" : "Ha habido un error al guardar el estado",
    "There was an error clearing the status" : "Ha habido un error al eliminar el estado",
    "No recent status changes" : "No hay cambios de estado recientes",
    "Away" : "Ausente",
    "Do not disturb" : "No molestar",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "No eliminar",
    "Today" : "Hoy",
    "This week" : "Esta semana",
    "Online" : "En línea",
    "Invisible" : "Invisible",
    "Offline" : "Sin conexión",
    "There was an error saving the new status" : "Ha habido un error al guardar el nuevo estado",
    "30 minutes" : "30 minutos",
    "1 hour" : "1 hora",
    "4 hours" : "4 horas",
    "Mute all notifications" : "Silenciar todas las notificaciones",
    "Appear offline" : "Aparecer sin conexión",
    "Clear status message after" : "Borrar mensaje de estado después de",
    "What's your status?" : "¿Cuál es tu estado?"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
